==> haskell-network-protocol-xmpp-0.4.8-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-network-protocol-xmpp/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-protocol-xmpp
version: 0.4.8
id: network-protocol-xmpp-0.4.8-61c27ebba529d56259b65af781048b04
key: netwo_99Z3AWUunhk4Tc4jRBIv6v
license: GPL-3
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-xmpp/
synopsis: Client library for the XMPP protocol.
category: Network
author: John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>
exposed: True
exposed-modules:
    Network.Protocol.XMPP
hidden-modules: Network.Protocol.XMPP.Client
                Network.Protocol.XMPP.Client.Authentication
                Network.Protocol.XMPP.Client.Features
                Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
                Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
                Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
                Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/network-protocol-xmpp-0.4.8
library-dirs: /usr/lib/ghc-7.10.3/site-local/network-protocol-xmpp-0.4.8
data-dir: /usr/share/arm-linux-ghc-7.10.3/network-protocol-xmpp-0.4.8
hs-libraries: HSnetwork-protocol-xmpp-0.4.8-99Z3AWUunhk4Tc4jRBIv6v
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    gnuidn-0.2.2-34fff2bd0e993d3a52572da37219c072
    gnutls-0.2-8df9baa3e646be4b43083fa069a940a0
    gsasl-0.3.6-675ae69617ad67a14a7dd583e0c2e57a
    libxml-sax-0.7.5-624f5c521370cadad57e680879f43d42
    monads-tf-0.1.0.2-fdcac0b12e43d8f2d2c7bd2854843ca0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    xml-types-0.3.6-0a5622d83032677699f095224f223b42
haddock-interfaces: /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock
haddock-html: /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-protocol-xmpp-0.4.8-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-network-protocol-xmpp/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-protocol-xmpp
version: 0.4.8
id: network-protocol-xmpp-0.4.8-d8a7f0b718b475a69de2ec39147fcdbf
key: netwo_7JD0XiTkmU422OMlGERrXQ
license: GPL-3
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-xmpp/
synopsis: Client library for the XMPP protocol.
category: Network
author: John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>
exposed: True
exposed-modules:
    Network.Protocol.XMPP
hidden-modules: Network.Protocol.XMPP.Client
                Network.Protocol.XMPP.Client.Authentication
                Network.Protocol.XMPP.Client.Features
                Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
                Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
                Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
                Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/network-protocol-xmpp-0.4.8
library-dirs: /usr/lib/ghc-7.10.3/site-local/network-protocol-xmpp-0.4.8
data-dir: /usr/share/arm-linux-ghc-7.10.3/network-protocol-xmpp-0.4.8
hs-libraries: HSnetwork-protocol-xmpp-0.4.8-7JD0XiTkmU422OMlGERrXQ
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    gnuidn-0.2.2-75590053994dafdd6c4849443170b273
    gnutls-0.2-8df9baa3e646be4b43083fa069a940a0
    gsasl-0.3.6-675ae69617ad67a14a7dd583e0c2e57a
    libxml-sax-0.7.5-856c4308eb4976385a108d5795d6f217
    monads-tf-0.1.0.2-fdcac0b12e43d8f2d2c7bd2854843ca0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    xml-types-0.3.6-c95586b34c41769092e7d9cdd505a61e
haddock-interfaces: /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock
haddock-html: /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
